/*
	FILE:	MG_DC_Mode.h
	
	AUTHOR:	Brent Pease
	
	CREATED: July 31, 1999
	
	PURPOSE: 
	
	Copyright 1997 - 1999

*/
#ifndef MG_DRAWENGINE_MODE_H
#define MG_DRAWENGINE_MODE_H

void
MGrMode_Point(
	void);

void
MGrMode_Line_Gouraud_InterpNone(
	void);

void
MGrMode_Line_Gouraud_InterpVertex(
	void);

void
MGrMode_Solid_Gouraud_InterpNone(
	void);

void
MGrMode_Solid_Gouraud_InterpVertex(
	void);

void
MGrMode_Solid_TextureLit_InterpNone_LMOff_1TMU(
	void);

void
MGrMode_Solid_TextureLit_InterpNone_LMOn_1TMU(
	void);

void
MGrMode_Solid_TextureLit_InterpNone_LMOnly_1TMU(
	void);

void
MGrMode_Solid_TextureLit_InterpVertex_LMOff_1TMU(
	void);

void
MGrMode_Solid_TextureLit_InterpVertex_LMOn_1TMU(
	void);

void
MGrMode_Solid_TextureLit_InterpVertex_LMOnly_1TMU(
	void);

void
MGrMode_Solid_TextureUnlit_InterpNone_LMOff_1TMU(
	void);

void
MGrMode_Solid_TextureUnlit_InterpNone_LMOn_1TMU(
	void);

void
MGrMode_Solid_TextureUnlit_InterpNone_LMOnly_1TMU(
	void);

void
MGrMode_Solid_TextureUnlit_InterpVertex_LMOff_1TMU(
	void);

void
MGrMode_Solid_TextureUnlit_InterpVertex_LMOn_1TMU(
	void);

void
MGrMode_Solid_TextureUnlit_InterpVertex_LMOnly_1TMU(
	void);

//
void
MGrMode_Solid_TextureLit_InterpNone_LMOff_2TMU(
	void);

void
MGrMode_Solid_TextureLit_InterpNone_LMOn_2TMU(
	void);

void
MGrMode_Solid_TextureLit_InterpNone_LMOnly_2TMU(
	void);

void
MGrMode_Solid_TextureLit_InterpVertex_LMOff_2TMU(
	void);

void
MGrMode_Solid_TextureLit_InterpVertex_LMOn_2TMU(
	void);

void
MGrMode_Solid_TextureLit_InterpVertex_LMOnly_2TMU(
	void);

void
MGrMode_Solid_TextureUnlit_InterpNone_LMOff_2TMU(
	void);

void
MGrMode_Solid_TextureUnlit_InterpNone_LMOn_2TMU(
	void);

void
MGrMode_Solid_TextureUnlit_InterpNone_LMOnly_2TMU(
	void);

void
MGrMode_Solid_TextureUnlit_InterpVertex_LMOff_2TMU(
	void);

void
MGrMode_Solid_TextureUnlit_InterpVertex_LMOn_2TMU(
	void);

void
MGrMode_Solid_TextureUnlit_InterpVertex_LMOnly_2TMU(
	void);



#endif /* MG_DRAWENGINE_MODE_H */
